==> eslint-plugin-check-file-1.2.0.tgz: package/lib/rules/folder-match-with-fex.js <==
/**
 * @fileoverview The folder should match the naming pattern specified by the file extension
 * @author Duke Luo
 */
'use strict';

const { getFolderPath, getFilename } = require('../utils/filename');
const { checkSettings, globPatternValidator } = require('../utils/settings');
const { getDocUrl } = require('../utils/doc');
const { matchRule } = require('../utils/match');

/**
 * @type {import('eslint').Rule.RuleModule}
 */
module.exports = {
  meta: {
    type: 'layout',
    docs: {
      description:
        'The folder should match the naming pattern specified by the file extension',
      category: 'Layout & Formatting',
      recommended: false,
      url: getDocUrl('folder-match-with-fex'),
    },
    fixable: null,
    schema: [
      {
        additionalProperties: {
          type: 'string',
        },
      },
    ],
  },

  create(context) {
    return {
      Program: (node) => {
        const rules = context.options[0];

        const invalidPattern = checkSettings(
          rules,
          globPatternValidator,
          globPatternValidator
        );

        if (invalidPattern) {
          context.report({
            node,
            message:
              'There is an invalid pattern "{{invalidPattern}}", please check it',
            data: {
              invalidPattern,
            },
          });
          return;
        }

        const filenameWithPath = context.getFilename();
        const filename = getFilename(filenameWithPath);
        const folderPath = getFolderPath(filenameWithPath);

        for (const [fexPattern, folderPattern] of Object.entries(rules)) {
          const matchResult = matchRule(
            filename,
            fexPattern,
            folderPath,
            folderPattern
          );

          if (matchResult) {
            const { pattern } = matchResult;
            context.report({
              node,
              message:
                'The folder of the file "{{filenameWithPath}}" does not match "{{pattern}}"',
              data: {
                filenameWithPath,
                pattern,
              },
            });
            return;
          }
        }
      },
    };
  },
};

==> eslint-plugin-check-file-1.2.1.tgz: package/lib/rules/folder-match-with-fex.js <==
/**
 * @fileoverview The folder should match the naming pattern specified by the file extension
 * @author Duke Luo
 */
'use strict';

const { getFolderPath, getFilename } = require('../utils/filename');
const { checkSettings, globPatternValidator } = require('../utils/settings');
const { getDocUrl } = require('../utils/doc');
const { matchRule } = require('../utils/match');

/**
 * @type {import('eslint').Rule.RuleModule}
 */
module.exports = {
  meta: {
    type: 'layout',
    docs: {
      description:
        'The folder should match the naming pattern specified by the file extension',
      category: 'Layout & Formatting',
      recommended: false,
      url: getDocUrl('folder-match-with-fex'),
    },
    fixable: null,
    schema: [
      {
        additionalProperties: {
          type: 'string',
        },
      },
    ],
  },

  create(context) {
    return {
      Program: (node) => {
        const rules = context.options[0];

        const invalidPattern = checkSettings(
          rules,
          globPatternValidator,
          globPatternValidator
        );

        if (invalidPattern) {
          context.report({
            node,
            message:
              'There is an invalid pattern "{{invalidPattern}}", please check it',
            data: {
              invalidPattern,
            },
          });
          return;
        }

        const filenameWithPath = context.getPhysicalFilename();
        const filename = getFilename(filenameWithPath);
        const folderPath = getFolderPath(filenameWithPath);

        for (const [fexPattern, folderPattern] of Object.entries(rules)) {
          const matchResult = matchRule(
            filename,
            fexPattern,
            folderPath,
            folderPattern
          );

          if (matchResult) {
            const { pattern } = matchResult;
            context.report({
              node,
              message:
                'The folder of the file "{{filenameWithPath}}" does not match "{{pattern}}"',
              data: {
                filenameWithPath,
                pattern,
              },
            });
            return;
          }
        }
      },
    };
  },
};
